@@ -251,14 +251,28 @@ def transform_star_call_code(content):
                         copy_arg_info_list)
                     arg_str_list = [ast.unparse(arg) for arg in arg_info_list[0]]
                     call_star=arg_info_list[-1]
+                    call_star_lineno_start=call_star.lineno
                     call_star_start=call_star.col_offset
                     part_code=ast.get_source_segment(content,call_star)
-                    # print("part_code: ", part_code)
-                    arg_str=part_code[arg_info_list[0][0].col_offset-call_star_start:arg_info_list[0][-1].end_col_offset-call_star_start]
+                    # print("call star part_code: ", part_code)
+                    part_code_list=part_code.split("\n")
+
+                    arg_str_list=[]
+                    for ind_arg,e_arg in enumerate(part_code.split("\n")):
+                        if ind_arg==0:
+                            arg_str_list.append(e_arg[arg_info_list[0][0].col_offset-call_star_start:])
+                        elif arg_info_list[0][-1].end_lineno-call_star_lineno_start>ind_arg>=1:
+                            arg_str_list.append(e_arg)
+                        else:
+                            arg_str_list.append(e_arg[:arg_info_list[0][-1].end_col_offset])
+
+                    # arg_str=part_code[arg_info_list[0][0].col_offset-call_star_start:arg_info_list[0][-1].end_col_offset-call_star_start]
 
                     line_list = [[(arg_info_list[0][0].lineno,arg_info_list[0][0].col_offset), (arg_info_list[0][-1].end_lineno,arg_info_list[0][-1].end_col_offset)]]
                     code_pair_list.append(
-                        [class_name, me_name, [arg_str], [ast.unparse(star_node)], line_list])
+                        [class_name, me_name, ["\n".join(arg_str_list)], [ast.unparse(star_node)], line_list])
+                    # code_pair_list.append(
+                    #     [class_name, me_name, arg_str_list, new_code_arg_list, line_list])
 
                     # line_list=[[arg_info_list[0][0].lineno,arg_info_list[0][0].end_lineno]]
                     # code_pair_list.append([class_name,me_name,",".join(arg_str_list), ast.unparse(star_node),line_list])
@@ -269,6 +283,61 @@ def transform_star_call_code(content):
     except:
         traceback.print_exc()
         return code_pair_list
+def get_info_from_code_fragment(content):
+    code_pair_list = []
+    # print(content)
+    try:
+
+        tree = ast.parse(content)
+        # ana_py = ast_util.Fun_Analyzer()
+        # ana_py.visit(file_tree)
+
+        if 1:#for tree, class_name in ana_py.func_def_list:
+            try:
+                me_name = tree.name
+            except:
+                me_name = ""
+            new_arg_same_list = get_func_call_by_args(tree)
+
+            for ind, arg_info_list in enumerate(new_arg_same_list):
+                copy_arg_info_list = copy.deepcopy(arg_info_list)
+                star_node = transform_var_unpack_call_compli_to_simple.transform_var_unpack_call_each_args(
+                    copy_arg_info_list)
+                arg_str_list = [ast.unparse(arg) for arg in arg_info_list[0]]
+                call_star = arg_info_list[-1]
+                call_star_lineno_start = call_star.lineno
+                call_star_start = call_star.col_offset
+                part_code = ast.get_source_segment(content, call_star)
+                # print("call star part_code: ", part_code)
+                part_code_list = part_code.split("\n")
+
+                arg_str_list = []
+                for ind_arg, e_arg in enumerate(part_code.split("\n")):
+                    if ind_arg == 0:
+                        arg_str_list.append(e_arg[arg_info_list[0][0].col_offset - call_star_start:])
+                    elif arg_info_list[0][-1].end_lineno - call_star_lineno_start > ind_arg >= 1:
+                        arg_str_list.append(e_arg)
+                    else:
+                        arg_str_list.append(e_arg[:arg_info_list[0][-1].end_col_offset])
+
+                # arg_str=part_code[arg_info_list[0][0].col_offset-call_star_start:arg_info_list[0][-1].end_col_offset-call_star_start]
+
+                line_list = [[(arg_info_list[0][0].lineno, arg_info_list[0][0].col_offset),
+                              (arg_info_list[0][-1].end_lineno, arg_info_list[0][-1].end_col_offset)]]
+                code_pair_list.append(
+                    ['', me_name, ["\n".join(arg_str_list)], [ast.unparse(star_node)], line_list])
+                # code_pair_list.append(
+                #     [class_name, me_name, arg_str_list, new_code_arg_list, line_list])
+
+                # line_list=[[arg_info_list[0][0].lineno,arg_info_list[0][0].end_lineno]]
+                # code_pair_list.append([class_name,me_name,",".join(arg_str_list), ast.unparse(star_node),line_list])
+
+        return code_pair_list
+
+    except:
+        traceback.print_exc()
+        return code_pair_list
+
 def save_repo_for_else_complicated(repo_name):
     start=time.time()
     count_complicated_code = 0
