@@ -250,8 +250,8 @@ def transform_line_no(code_list):
     sorted_new_code_list=sorted(new_code_list, key=lambda i: (i[0],-i[1]))
 
     # print("sorted_new_code_list")
-    for e in sorted_new_code_list:
-        print(e)
+    # for e in sorted_new_code_list:
+    #     print(e)
     return sorted_new_code_list
 def replace_code(lineno_list,simp_code, code_fragment_list, bias=0):
     # lineno_list = chain_compare_code[-1]
@@ -452,6 +452,7 @@ def file_replace(abs_path, each_file_code_list):
                             # print(">>>*********new_content:\n", "".join(new_content))
 
                         continue
+                    # print("code_pair_list: ",code_pair_list)
                     new_lineno_list = code_pair_list[0][-1]
                     # # compli_code=chain_compare_code[-4]
                     simp_code = code_pair_list[0][-2]
@@ -500,10 +501,13 @@ def main(args):
         a.append(i)
     # envname = args.envname
     if os.path.isdir(filepath):
+        if os.path.exists(output_dir):
+            shutil.rmtree(output_dir)
         for path,dir_list,file_list in os.walk(filepath):
             for file_name in file_list:
                 abs_path=os.path.join(path,file_name)
                 save_dir=path[len(filepath):]
+                # print(">>>>>save_dir: ",save_dir)
                 if abs_path.endswith(".py"):
                     print(f"************For File {abs_path.split('/')[-1]}, begin to find refactorable non-idiomatic code with Python idioms************")
 
@@ -511,17 +515,15 @@ def main(args):
                     each_file_code_list,dict_code_pair=get_refactoring(idiom, code_frag,abs_path)
                     # print(code_pair_list)
                     if not flag_outputdir_mergeallcodepair:
-                        if os.path.exists(output_dir):
-                            shutil.rmtree(output_dir)
+
                         for ind_save,each_code_pair in enumerate(each_file_code_list):
                             new_content=file_replace(abs_path,[each_code_pair])
-
+                            # print(">>>>>output_dir: ", output_dir,save_dir)
                             util.save_file_path("".join([output_dir,save_dir,"/",file_name[:-3],'_',str(ind_save),'.py']),new_content)
 
                     else:
                         new_content=file_replace(abs_path,each_file_code_list)
-                        if os.path.exists(output_dir):
-                            shutil.rmtree(output_dir)
+
                         util.save_file_path("".join([output_dir,save_dir,"/",file_name]),new_content)
                     print(f"************Result of {abs_path.split('/')[-1]} End************")
 
@@ -562,19 +564,19 @@ if __name__ == '__main__':
     parser = argparse.ArgumentParser(description='RefactoringIdioms')
     parser.add_argument('--envname', type=str,
                         help='envname', default="CartPole-v0")
-    parser.add_argument('--filepath', type=str,
-                        help='filepath', default=abs_path+"/file.py")
+    # parser.add_argument('--filepath', type=str,
+    #                     help='filepath', default=abs_path+"/file.py")
     # parser.add_argument('--filepath', type=str,
     #                     help='filepath', default=abs_path + "/")
-    # parser.add_argument('--filepath', type=str,
-    #                     help='filepath', default= "./")
+    parser.add_argument('--filepath', type=str,
+                        help='filepath', default= "./")
     #
     parser.add_argument('--idiom', type=str,
                         help='idiom', default="All")
     parser.add_argument('--outputdir', type=str,
-                        help='outputdir', default=abs_path+"RefactoringIdiomsOutputdir/")
+                        help='outputdir', default="./RefactoringIdiomsOutputdir/")
     parser.add_argument('--flag_merge_allcodepair', type=str,
-                        help='flag_merge_allcodepair', default=0)
+                        help='flag_merge_allcodepair', default=1)
     parser.add_argument('--output_codepair', type=str,
                         help='output_codepair', default="result.json")
     parser.add_argument('--flag_console_output', type=str,
